@@ -1,4 +1,6 @@
 #' 
+#' 
+#' 
 #' @title Average predictions from several (non)linear models based on IC weights
 #' @name predict_nls
 #' @rdname predict_nls
@@ -17,8 +19,8 @@
 #' a data.frame with columns named (for a 0.95 level) \sQuote{Estimate}, \sQuote{Est.Error}, \sQuote{Q2.5} and \sQuote{Q97.5}
 #' @note all the objects should be fitted to the same data. Weights are
 #' based on the chosen IC value (exp(-0.5 * delta IC)). 
-#' For models of class \code{\link[mgcv]{gam}} there is very limited support.
-#' @seealso \code{\link[stats]{predict.lm}}, \code{\link[stats]{predict.nls}}, \code{\link[mgcv]{predict.gam}}, \code{\link{simulate_nls}}, \code{\link{simulate_gam}}
+#' For models of class [mgcv::gam()] there is very limited support.
+#' @seealso [stats::predict.lm()], [stats::predict.nls()], [mgcv::predict.gam()], [simulate_nls()], [simulate_gam()]
 #' @export
 #' @examples
 #' \donttest{
@@ -85,7 +87,7 @@ predict_nls <- function(..., criteria = c("AIC", "AICc", "BIC"),
   
   for(i in seq_len(lobjs)){
     nls.obj <- nls.objs[[i]]
-    if(!inherits(nls.obj, c("nls","lm"))) stop("All objects should be of class 'nls' or 'lm'")
+    if(!inherits(nls.obj, c("nls","lm"))) stop("All objects should inherit class 'nls' or 'lm'")
     if(data.name != as.character(nls.obj$call$data)) stop("All models should be fitted to the same data")
     
     wtab$model[i] <- nls.nms[i]
@@ -356,9 +358,10 @@ predict_gam <- function(object, newdata=NULL, type="link", se.fit=TRUE, terms=NU
     if(missing(tvalue)){
       tvalue <- stats::qt(level, df = object$df.residual)
     }
-    lwr <- prd$fit - tvalue * sqrt(prd$se.fit^2 + sigma(object)^2)
-    upr <- prd$fit + tvalue * sqrt(prd$se.fit^2 + sigma(object)^2)
-    ans <- data.frame(Estimate = prd$fit, Est.Error = prd$se.fit, lwr = lwr, upr = upr)
+    se.fit.pred <- sqrt(prd$se.fit^2 + sigma(object)^2)
+    lwr <- prd$fit - tvalue * se.fit.pred
+    upr <- prd$fit + tvalue * se.fit.pred
+    ans <- data.frame(Estimate = prd$fit, Est.Error = se.fit.pred, lwr = lwr, upr = upr)
     names(ans) <- c("Estimate", "Est.Error", paste0("Q", 100*(1 - level)/2), paste0("Q", 100 * (1 - (1 - level)/2)))
   }
   return(ans)
@@ -445,7 +448,7 @@ predict2_nls <- function(object, newdata = NULL,
                          level = 0.95){
   
   if(!inherits(object, "nls"))
-    stop("This function is only for objects of class 'nls'")
+    stop("This function is only for objects which inherit class 'nls'")
   
   interval <- match.arg(interval)
   npar <- length(coef(object))
@@ -459,12 +462,16 @@ predict2_nls <- function(object, newdata = NULL,
     grd <- attr(prd, "gradient") ## retrieves the gradient  
     if(is.null(grd)){
       if(is.null(newdata)){
+        ### I guess this works because although the gradient 
+        ### is not available as an attribute, it will still be computed
         grd <- object$m$gradient()
         colnames(grd) <- names(coef(object))
       }else{
         ## Need to approximate the gradient numerically
         form <- object$m$formula()
-        grd0 <- with(newdata, numericDeriv(form[[3]], names(coef(object))))
+        cfs <- as.list(coef(object))
+        nenv <- list2env(c(cfs, unclass(newdata)))
+        grd0 <- stats::numericDeriv(form[[3]], names(coef(object)), rho = nenv)
         grd <- attr(grd0, "gradient")
       }
     }
